@@ -3,6 +3,8 @@
 
 #test as_odf_table
 test_that("as_odf_tbl", {
+  skip_if(packageVersion("tibble") < "3.2.1",
+          "tibble >= 3.2.1 required")
   # create dataframe
   df <- data.frame(id = 1:5, name = c("Klaus", "Anna", "Rebecca", "Kevin", "Janina"), age = c(55, 40, 19, 25, 60), diagnosis = c(1,3,3,2,1))
   # Add metadata for dataset
@@ -26,10 +28,8 @@ test_that("as_odf_tbl", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label_en", "description_en", "url",
-                                            "languages", "lang", "label", 
-                                            "class"))
+  expect_true(all(c("name", "label_en", "description_en", "url",
+                    "languages", "lang", "label") %in% names(attributes(df_out))))
   expect_equal(attributes(df_out)[["name"]],
                "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en"))
@@ -66,10 +66,7 @@ test_that("as_odf_tbl", {
   
   df_out <- as_odf_tbl(df, active_language = "en")
   # - dataset attributes
-  expect_equal(names(attributes(df_out)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
+  expect_true(all(c("names",
     "study",
     "name",
     "description_en",
@@ -79,27 +76,24 @@ test_that("as_odf_tbl", {
     "url",
     "languages",
     "lang",
-    "label",
-    "class"
-  ))
+    "label") %in% names(attributes(df_out))))
+  
   # - variable attributes
-  expect_equal(names(attributes(df_out$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c(    "name",
+                        "label_en",
+                        "label_de",
+                        "description_en",
+                        "description_de",
+                        "type",
+                        "url",
+                        "labels_en",
+                        "labels_de",
+                        "languages",
+                        "lang",
+                        "label") %in% names(attributes(df_out$bap87))))
   # - dataset content
   expect_equal(attributes(df_out)$names, c("bap87", "bap9201", "bap9001", "bap9002",
-                                       "bap9003", "bap96", "name"))
+                                           "bap9003", "bap96", "name"))
   expect_equal(attributes(df_out)$name, "bap")
   expect_equal(attributes(df_out)$label, "Data from individual questionnaires 2010")
   expect_equal(attributes(df_out)$label_de, "Daten vom Personenfragebogen 2010")
@@ -140,45 +134,39 @@ test_that("as_odf_tbl", {
   df_out <- as_odf_tbl(df, active_language = "en")
   
   # - dataset attributes
-  expect_equal(names(attributes(df_out)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_NA",
-    "description_en",
-    "description_de",
-    "label_NA",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_NA",
+                    "description_en",
+                    "description_de",
+                    "label_NA",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df_out))))
+  
   # - variable attributes
-  expect_equal(names(attributes(df_out$bap87)), c(
-    "name",
-    "label_NA",
-    "label_en",
-    "label_de",
-    "description_NA",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_NA",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_NA",
+                    "label_en",
+                    "label_de",
+                    "description_NA",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_NA",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df_out$bap87))))
   # - dataset content
   expect_equal(attributes(df_out)$names, c("bap87", "bap9201", "bap9001",
-                                       "bap9002", "bap9003", "bap96", "name"))
+                                           "bap9002", "bap9003", "bap96", "name"))
   expect_equal(attributes(df_out)$name, "bap")
   expect_equal(attributes(df_out)$url, "https://paneldata.org/soep-core/data/bap")
   expect_equal(attributes(df_out)$class,  c("odf_tbl", "tbl_df", "tbl", "data.frame"))
@@ -197,15 +185,15 @@ test_that("as_odf_tbl", {
   expect_equal(colnames(df_out), c("mpg", "cylinders", "displacement",
                                    "horsepower", "weight", "acceleration",
                                    "year", "origin", "name"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names",
-                                            "languages", "lang", 
-                                            "class"))
+
+  expect_true(all(c("names", "languages", "lang") %in% names(attributes(df_out))))
+  
   expect_equal(attributes(df_out)[["name"]],
                NULL)
   expect_equal(attributes(df_out)[["languages"]], c("NA"))
   expect_equal(attributes(df_out)[["lang"]], "NA")
   expect_equal(attributes(df_out)[["label"]], NULL)
-
+  
   expect_equal(attributes(df_out$mpg)[["label"]], NULL)
   expect_equal(attributes(df_out$mpg)[["name"]], "mpg")
   expect_equal(attributes(df_out$mpg)[["languages"]], "NA")
@@ -240,10 +228,12 @@ test_that("as_odf_tibble with metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label", "url", "label_NA",
-                                            "description_NA", "languages",
-                                            "lang", "class"))
+
+  expect_true(all(c("names", "name",
+                    "label", "url", "label_NA",
+                    "description_NA", "languages",
+                    "lang") %in% names(attributes(df_out))))
+  
   expect_equal(attributes(df_out)[["name"]], "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("NA"))
   expect_equal(attributes(df_out)[["lang"]], "NA")
@@ -277,11 +267,11 @@ test_that("as_odf_tibble with metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label", "url",
-                                            "label_en", "description_en",
-                                            "languages", "lang",
-                                            "class"))
+
+  expect_true(all(c("names", "name",
+                    "label", "url",
+                    "label_en", "description_en",
+                    "languages", "lang") %in% names(attributes(df_out))))
   expect_equal(attributes(df_out)[["name"]],
                "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en"))
@@ -347,11 +337,12 @@ test_that("as_odf_tibble active language argument and metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label_en", "label", 
-                                            "description_en", "url", "label_NA",
-                                            "description_NA",
-                                            "languages", "lang", "class"))
+
+  expect_true(all(c("names", "name",
+                    "label_en", "label", 
+                    "description_en", "url", "label_NA",
+                    "description_NA",
+                    "languages", "lang")%in% names(attributes(df_out))))
   expect_equal(attributes(df_out)[["name"]], "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en", "NA"))
   expect_equal(attributes(df_out)[["lang"]], "en")
@@ -398,11 +389,12 @@ test_that("as_odf_tibble active language argument and metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label_en", "label", 
-                                            "description_en", "url", "label_de",
-                                            "description_de",
-                                            "languages", "lang", "class"))
+  expect_true(all(c("names", "name",
+                    "label_en", "label", 
+                    "description_en", "url", "label_de",
+                    "description_de",
+                    "languages", "lang") %in% names(attributes(df_out))))
+  
   expect_equal(attributes(df_out)[["name"]], "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out)[["lang"]], "en")
@@ -448,11 +440,11 @@ test_that("as_odf_tibble active language argument and metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label_en", "label", 
-                                            "description_en", "url", "label_de",
-                                            "description_de",
-                                            "languages", "lang", "class"))
+  expect_true(all(c("names", "name",
+                    "label_en", "label", 
+                    "description_en", "url", "label_de",
+                    "description_de",
+                    "languages", "lang") %in% names(attributes(df_out))))
   expect_equal(attributes(df_out)[["name"]], "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out)[["lang"]], "de")
@@ -480,7 +472,7 @@ test_that("as_odf_tibble active language argument and metadata without a tag", {
   expect_equal(attributes(df_out$diagnosis)[["label"]], "Diagnose")
   expect_equal(attributes(df_out$diagnosis)[["label_en"]], "Diagnosis")
   expect_equal(attributes(df_out$diagnosis)[["label_de"]], "Diagnose")
-    expect_equal(attributes(df_out$diagnosis)[["description_en"]], "Diagnosis patient last visit")
+  expect_equal(attributes(df_out$diagnosis)[["description_en"]], "Diagnosis patient last visit")
   expect_equal(attributes(df_out$diagnosis)[["description_de"]], "Diagnose Patient letzter Besuch")
   expect_equal(attributes(df_out$diagnosis)[["description"]], NULL)
   
@@ -497,11 +489,11 @@ test_that("as_odf_tibble active language argument and metadata without a tag", {
   expect_equal(class(df_out), c("odf_tbl", "tbl_df", "tbl", "data.frame"))
   expect_equal(dim(df_out), c(5, 4))
   expect_equal(colnames(df_out), c("id", "name", "age", "diagnosis"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", "name",
-                                            "label_en", "label", 
-                                            "description_en", "url", "label_de",
-                                            "description_de",
-                                            "languages", "lang", "class"))
+  expect_true(all(c("names", "name",
+                    "label_en", "label", 
+                    "description_en", "url", "label_de",
+                    "description_de",
+                    "languages", "lang") %in% names(attributes(df_out))))
   expect_equal(attributes(df_out)[["name"]], "patientdata")
   expect_equal(attributes(df_out)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out)[["lang"]], "en")
