@@ -1,41 +1,36 @@
 #' read_odf: all languages
 test_that("read_odf_all", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- opendataformat::read_odf(
     file = "testdata/data.odf.zip",
     languages = "all"
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+  
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001", "bap9002",
                                        "bap9003", "bap96", "name"))
@@ -72,42 +67,37 @@ test_that("read_odf_all", {
 })
 
 test_that("read_odf_all", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- opendataformat::read_odf(
     file = "testdata/data.zip",
     languages = "all"
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+  
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001", "bap9002",
                                        "bap9003", "bap96", "name"))
@@ -146,47 +136,42 @@ test_that("read_odf_all", {
 
 #' read_odf: with default language
 test_that("read_odf_variables", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data_with_default.odf.zip",
     languages = "all"
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_NA",
-    "description_en",
-    "description_de",
-    "label_NA",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_NA",
+                    "description_en",
+                    "description_de",
+                    "label_NA",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_NA",
-    "label_en",
-    "label_de",
-    "description_NA",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_NA",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  
+  expect_true(all(c("name",
+                    "label_NA",
+                    "label_en",
+                    "label_de",
+                    "description_NA",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_NA",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001",
                                        "bap9002", "bap9003", "bap96", "name"))
@@ -202,37 +187,31 @@ test_that("read_odf_variables", {
 
 #' read_odf: "de" languages
 test_that("read_odf_de", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     languages = "de"
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_de",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_de",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_de",
-    "description_de",
-    "type",
-    "url",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_de",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001",
                                        "bap9002", "bap9003", "bap96", "name"))
@@ -259,42 +238,36 @@ test_that("read_odf_de", {
 
 #' read_odf: nrows=10
 test_that("read_odf_specific_rows", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     nrows = 10
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001", "bap9002",
                                        "bap9003", "bap96", "name"))
@@ -337,43 +310,38 @@ test_that("read_odf_specific_rows", {
 
 #' read_odf: nrows = 13, skip = 3
 test_that("read_odf_specific_rows2", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     nrows = 13,
     skip = 3
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+  
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9001",
                                        "bap9002", "bap9003", "bap96", "name"))
@@ -417,42 +385,38 @@ test_that("read_odf_specific_rows2", {
 
 #' read_odf: select =c(1,2,4,5)
 test_that("read_odf_specific_variables", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     select = c(1, 2, 4, 5)
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
+  
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+  
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9002",
                                        "bap9003"))
@@ -479,43 +443,38 @@ test_that("read_odf_specific_variables", {
 
 #' read_odf: select = c("bap87", "bap96", "bap9002", "bap9003")
 test_that("read_odf_specific_variables", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     select = c("bap87", "bap96", "bap9002",
                "bap9003")
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap96", "bap9002",
                                        "bap9003"))
@@ -560,6 +519,7 @@ test_that("read_odf_specific_variables", {
 
 #' read_odf: rows and cols
 test_that("read_odf_specific_rows_and_cols", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     nrows = 13,
@@ -567,37 +527,31 @@ test_that("read_odf_specific_rows_and_cols", {
     select = c(1, 2, 4, 5)
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9002",
                                        "bap9003"))
@@ -646,6 +600,7 @@ test_that("read_odf_specific_rows_and_cols", {
 
 #' read_odf: rows and cols2
 test_that("read_odf_specific_rows_and_cols2", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     nrows = 13,
@@ -654,37 +609,31 @@ test_that("read_odf_specific_rows_and_cols2", {
                "bap9003")
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_en",
-    "description_de",
-    "label_en",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_en",
+                    "description_de",
+                    "label_en",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_en",
-    "label_de",
-    "description_en",
-    "description_de",
-    "type",
-    "url",
-    "labels_en",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_en",
+                    "label_de",
+                    "description_en",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_en",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+  
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9002",
                                        "bap9003"))
@@ -733,6 +682,7 @@ test_that("read_odf_specific_rows_and_cols2", {
 
 #' read_odf: language rows and cols
 test_that("read_odf_specific_language_rows_and_cols", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   df <- read_odf(
     file = "testdata/data.odf.zip",
     nrows = 13,
@@ -742,32 +692,27 @@ test_that("read_odf_specific_language_rows_and_cols", {
     languages = "de"
   )
   # - dataset attributes
-  expect_equal(names(attributes(df)), c(
-    "row.names",
-    "names",
-    ".internal.selfref",
-    "study",
-    "name",
-    "description_de",
-    "label_de",
-    "url",
-    "languages",
-    "lang",
-    "label",
-    "class"
-  ))
+  expect_true(all(c("names",
+                    "study",
+                    "name",
+                    "description_de",
+                    "label_de",
+                    "url",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df))))
+
   # - variable attributes
-  expect_equal(names(attributes(df$bap87)), c(
-    "name",
-    "label_de",
-    "description_de",
-    "type",
-    "url",
-    "labels_de",
-    "languages",
-    "lang",
-    "label"
-  ))
+  expect_true(all(c("name",
+                    "label_de",
+                    "description_de",
+                    "type",
+                    "url",
+                    "labels_de",
+                    "languages",
+                    "lang",
+                    "label") %in% names(attributes(df$bap87))))
+
   # - dataset content
   expect_equal(attributes(df)$names, c("bap87", "bap9201", "bap9002",
                                        "bap9003"))
@@ -805,5 +750,5 @@ test_that("read_odf_specific_language_rows_and_cols", {
   expect_equal(unname(attributes(df$bap9201)$labels_de), c(-2, -1))
   expect_equal(names(attributes(df$bap9201)$labels_de),
                c("trifft nicht zu", "keine Angabe"))
-    unlink(paste0(tempdir(), "/*"), recursive = TRUE)
+  unlink(paste0(tempdir(), "/*"), recursive = TRUE)
 })
