@@ -3,6 +3,7 @@
 
 #test merging
 test_that("merge.odf", {
+  skip_if(packageVersion("tibble") < "3.2.1",  "tibble >= 3.2.1 required")
   #' - get data
   df1 <- read_odf("testdata/data.zip", select = c(1:4))
   df2 <- read_odf("testdata/data.zip", select = c(4:7))
@@ -11,9 +12,9 @@ test_that("merge.odf", {
   df5 <- read_odf("testdata/data.zip", select = c(6:7))
   df6 <- read_odf("testdata/data.zip")
   df7 <- read_odf("testdata/data.zip")
-
-
-
+  
+  
+  
   df1$id <- 1:20
   df2$id <- 1:20
   df3$id <- c(1:10, 1:10)
@@ -26,19 +27,23 @@ test_that("merge.odf", {
   df4$id2 <- c(1:10, 11:20)
   df5$id2 <- c(1:5, 16:20, 16:25)
   df7$id <- 1:20
-
-
+  
+  
   df_out <- merge(x = df1, y = df2)
   expect_equal(dim(df_out), c(15, 9))
   expect_equal(colnames(df_out), c("bap9002", "id", "id2", "bap87", "bap9201",
                                    "bap9001", "bap9003", "bap96", "name"))
-  expect_equal(names(attributes(df_out)), c("row.names", "names", ".internal.selfref", "sorted", "name",
-                                            "languages", "lang", "class"))
+  expect_true(all(c("names",
+                    "name",
+                    "languages",
+                    "lang",
+                    "class") %in% names(attributes(df_out))))
+
   expect_equal(attributes(df_out)[["name"]],
                "dataset merged from other datasets bap bap")
   expect_equal(attributes(df_out)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out)[["lang"]], "en")
-
+  
   expect_equal(attributes(df_out$bap9002)[["label_en"]],
                "Run-down, Melancholy Last 4 Weeks")
   expect_equal(attributes(df_out$bap87)[["label_de"]],
@@ -50,16 +55,16 @@ test_that("merge.odf", {
   expect_equal(attributes(df_out$bap9003)[["type"]], "numeric")
   expect_equal(attributes(df_out$bap96)[["url"]],
                "https://paneldata.org/soep-core/data/bap/bap96")
-
+  
   labels_en <- -2:-1
   names(labels_en) <- c("Does not apply", "No Answer")
   expect_equal(attributes(df_out$name)[["labels_en"]], labels_en)
-
+  
   labels_de <- c(-2, -1, 1:5)
   names(labels_de) <- c("trifft nicht zu", "keine Angabe", "Immer", "Oft",
                         "Manchmal", "Fast nie", "Nie")
   expect_equal(attributes(df_out$bap9002)[["labels_de"]], labels_de)
-
+  
   expect_equal(attributes(df_out$bap87)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out$bap9201)[["lang"]], "en")
   expect_equal(attributes(df_out$bap9003)[["label"]],
@@ -68,20 +73,24 @@ test_that("merge.odf", {
                "Well-balanced Last 4 Weeks")
   expect_equal(attributes(df_out$bap96)[["label_de"]], "Körpergröße")
   expect_equal(attributes(df_out$name)[["description_en"]], "Firstname")
-
-
+  
+  
   df_out <- merge(x = df3, y = df4)
   df_out2 <- merge(x = df_out, y = df5)
   expect_equal(dim(df_out2), c(10, 9))
   expect_equal(colnames(df_out2), c("id", "id2", "bap87", "bap9201", "bap9001",
-                                   "bap9002", "bap9003", "bap96", "name"))
-  expect_equal(names(attributes(df_out2)), c("row.names", "names", ".internal.selfref", "sorted", "name",
-                                             "languages", "lang", "class"))
+                                    "bap9002", "bap9003", "bap96", "name"))
+  expect_true(all(c("names",
+                    "name",
+                    "languages",
+                    "lang",
+                    "class") %in% names(attributes(df_out2))))
+
   expect_equal(attributes(df_out2)[["name"]],
                "dataset merged from other datasets bap bap bap")
   expect_equal(attributes(df_out2)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2)[["lang"]], "en")
-
+  
   expect_equal(attributes(df_out2$bap9002)[["label_en"]],
                "Run-down, Melancholy Last 4 Weeks")
   expect_equal(attributes(df_out2$bap9001)[["label_de"]],
@@ -93,16 +102,16 @@ test_that("merge.odf", {
   expect_equal(attributes(df_out2$bap9003)[["type"]], "numeric")
   expect_equal(attributes(df_out2$bap96)[["url"]],
                "https://paneldata.org/soep-core/data/bap/bap96")
-
+  
   labels_en <- -2:-1
   names(labels_en) <- c("Does not apply", "No Answer")
   expect_equal(attributes(df_out2$name)[["labels_en"]], labels_en)
-
+  
   labels_de <- c(-2, -1, 1:5)
   names(labels_de) <- c("trifft nicht zu", "keine Angabe", "Immer", "Oft",
                         "Manchmal", "Fast nie", "Nie")
   expect_equal(attributes(df_out2$bap9002)[["labels_de"]], labels_de)
-
+  
   expect_equal(attributes(df_out2$bap96)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2$bap9201)[["lang"]], "en")
   expect_equal(attributes(df_out2$bap9003)[["label"]],
@@ -113,20 +122,24 @@ test_that("merge.odf", {
                "Körpergröße")
   expect_equal(attributes(df_out2$name)[["description_en"]],
                "Firstname")
-
+  
   df_out <- merge(x = df1, y = df4)
   df_out2 <- merge(x = df_out, y = df5, by = c("id", "id2"))
   expect_equal(dim(df_out2), c(5, 9))
   expect_equal(colnames(df_out2), c("id", "id2", "bap9001", "bap9002", "bap87",
-                                   "bap9201",  "bap9003", "bap96", "name"))
-  expect_equal(names(attributes(df_out2)),
-               c("row.names", "names", ".internal.selfref", "sorted",  "name",
-                 "languages", "lang", "class"))
+                                    "bap9201",  "bap9003", "bap96", "name"))
+  expect_true(all(c("names",
+                    "name",
+                    "languages",
+                    "lang",
+                    "class") %in% names(attributes(df_out2))))
+  
+
   expect_equal(attributes(df_out2)[["name"]],
                "dataset merged from other datasets bap bap bap")
   expect_equal(attributes(df_out2)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2)[["lang"]], "en")
-
+  
   expect_equal(attributes(df_out2$bap9002)[["label_en"]],
                "Run-down, Melancholy Last 4 Weeks")
   expect_equal(attributes(df_out2$bap9001)[["label_de"]],
@@ -140,16 +153,16 @@ test_that("merge.odf", {
                "numeric")
   expect_equal(attributes(df_out2$bap96)[["url"]],
                "https://paneldata.org/soep-core/data/bap/bap96")
-
+  
   labels_en <- -2:-1
   names(labels_en) <- c("Does not apply", "No Answer")
   expect_equal(attributes(df_out2$name)[["labels_en"]], labels_en)
-
+  
   labels_de <- c(-2, -1, 1:5)
   names(labels_de) <- c("trifft nicht zu", "keine Angabe", "Immer", "Oft",
                         "Manchmal", "Fast nie", "Nie")
   expect_equal(attributes(df_out2$bap9002)[["labels_de"]], labels_de)
-
+  
   expect_equal(attributes(df_out2$bap96)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2$bap9201)[["lang"]], "en")
   expect_equal(attributes(df_out2$bap87)[["label"]], "Current Health")
@@ -157,22 +170,25 @@ test_that("merge.odf", {
                "Well-balanced Last 4 Weeks")
   expect_equal(attributes(df_out2$bap96)[["label_de"]], "Körpergröße")
   expect_equal(attributes(df_out2$name)[["description_en"]], "Firstname")
-
+  
   df_out <- merge(x = df1, y = df6)
   df_out2 <- merge(x = df2, y = df_out)
-
+  
   expect_equal(dim(df_out2), c(5, 9))
   expect_equal(colnames(df_out2), c("bap9002", "bap9003", "bap96", "name", "id",
                                     "id2", "bap87", "bap9201",
                                     "bap9001"))
-  expect_equal(names(attributes(df_out2)),
-               c("row.names", "names", ".internal.selfref", "sorted", "name",
-                 "languages", "lang", "class"))
+  expect_true(all(c("names",
+                    "name",
+                    "languages",
+                    "lang",
+                    "class") %in% names(attributes(df_out))))
+
   expect_equal(attributes(df_out2)[["name"]],
                "dataset merged from other datasets bap bap bap")
   expect_equal(attributes(df_out2)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2)[["lang"]], "en")
-
+  
   expect_equal(attributes(df_out2$bap9002)[["label_en"]],
                "Run-down, Melancholy Last 4 Weeks")
   expect_equal(attributes(df_out2$bap9001)[["label_de"]],
@@ -185,16 +201,16 @@ test_that("merge.odf", {
   expect_equal(attributes(df_out2$bap9003)[["type"]], "numeric")
   expect_equal(attributes(df_out2$bap96)[["url"]],
                "https://paneldata.org/soep-core/data/bap/bap96")
-
+  
   labels_en <- -2:-1
   names(labels_en) <- c("Does not apply", "No Answer")
   expect_equal(attributes(df_out2$name)[["labels_en"]], labels_en)
-
+  
   labels_de <- c(-2, -1, 1:5)
   names(labels_de) <- c("trifft nicht zu", "keine Angabe", "Immer", "Oft",
                         "Manchmal", "Fast nie", "Nie")
   expect_equal(attributes(df_out2$bap9002)[["labels_de"]], labels_de)
-
+  
   expect_equal(attributes(df_out2$bap96)[["languages"]], c("en", "de"))
   expect_equal(attributes(df_out2$bap9201)[["lang"]], "en")
   expect_equal(attributes(df_out2$bap87)[["label"]], "Current Health")
@@ -211,20 +227,20 @@ test_that("merge.odf", {
   #' - get data
   df1 <- read_odf("testdata/data.zip", select = c(1:4))
   df2 <- read_odf("testdata/data.zip", select = c(4:7))
-
-
+  
+  
   df1$id <- 1:20
   df2$id <- c(1:15, 1:5)
   df_out <- merge(x = df1, y = df2, all = FALSE)
   expect_equal(dim(df_out), c(15, 8))
-
+  
   df_out <- merge(x = df1, y = df2, all = TRUE)
   expect_equal(dim(df_out), c(25, 8))
-
+  
   df_out <- merge(x = df1, y = df2, all.x = FALSE, all.y = TRUE)
   expect_equal(dim(df_out), c(20, 8))
-
+  
   df_out <- merge(x = df1, y = df2, all.x = TRUE, all.y = FALSE)
   expect_equal(dim(df_out), c(20, 8))
-
-})
+  
+})
\ No newline at end of file
